<?php

namespace Classifieds\Category\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Classifieds\Category\Http\Requests\CategoryActionsRequest;
use Classifieds\Category\Actions\CategoryActions;

/**
 * Admin web controller class.
 */
class CategoryActionsController extends BaseController
{

    /**
     * Action controller function for category.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(CategoryActionsRequest $request, $action)
    {
        try {
            $category = CategoryActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('category::category.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('category/category/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('category/category/' . $action))
                ->redirect();
        }
    }
}
