<?php

namespace Classifieds\Category\Providers;

use Illuminate\Support\ServiceProvider;
use Classifieds\Category\Categories;

class CategoryServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'category');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'category');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();

        $this->app->register(\Classifieds\Category\Providers\AuthServiceProvider::class);
        $this->app->register(\Classifieds\Category\Providers\RouteServiceProvider::class);
        $this->app->register(\Classifieds\Category\Providers\ActionServiceProvider::class);
        $this->app->register(\Classifieds\Category\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('classifieds.category', function($app)
        {
            return $this->app->make(Category::class);
        });
    }

    /**
     * Merges user's and category's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'classifieds.category'
        );
        
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/category.php', 'classifieds.category.category'
        );
    }


    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['classifieds.category'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('classifieds/category')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/category')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/category')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
